@@ -113,7 +113,7 @@ def lineage(
                 )
             else:
                 if table not in tables:
-                    tables[table] = Node(name=table, source=source, expression=source)
+                    tables[table] = Node(name=c.sql(), source=source, expression=source)
                 node.downstream.append(tables[table])
 
         return node
